Exceptions — savepagenow documentation

# Exceptions

Custom errors you can expect.

exception savepagenow.exceptions.BlockedByRobots

  Bases: `savepagenow.exceptions.WaybackRuntimeError`

  Raised when archive.org has been blocked by the site’s robots.txt access control instructions.

exception savepagenow.exceptions.CachedPage

  Bases: `Exception`

  Raised when archive.org declines to make a new capture and instead returns the cached version of most recent archive.

exception savepagenow.exceptions.TooManyRequests

  Bases: `savepagenow.exceptions.WaybackRuntimeError`

  Raised when archive.org when you have exceeded its throttle on request frequency. Slow it down.

exception savepagenow.exceptions.WaybackRuntimeError

  Bases: `Exception`

  An error returned by the Wayback Machine.